summaryrefslogtreecommitdiff
path: root/libavdevice/alsa-audio.h
diff options
context:
space:
mode:
Diffstat (limited to 'libavdevice/alsa-audio.h')
-rw-r--r--libavdevice/alsa-audio.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libavdevice/alsa-audio.h b/libavdevice/alsa-audio.h
index 6719384d84..00acf9f3ee 100644
--- a/libavdevice/alsa-audio.h
+++ b/libavdevice/alsa-audio.h
@@ -39,7 +39,7 @@
/* XXX: we make the assumption that the soundcard accepts this format */
/* XXX: find better solution with "preinit" method, needed also in
other formats */
-#define DEFAULT_CODEC_ID AV_NE(CODEC_ID_PCM_S16BE, CODEC_ID_PCM_S16LE)
+#define DEFAULT_CODEC_ID AV_NE(AV_CODEC_ID_PCM_S16BE, AV_CODEC_ID_PCM_S16LE)
typedef void (*ff_reorder_func)(const void *, void *, int);
@@ -67,15 +67,15 @@ typedef struct {
* @param sample_rate in: requested sample rate;
* out: actually selected sample rate
* @param channels number of channels
* @param codec_id in: requested CodecID or CODEC_ID_NONE;
* out: actually selected CodecID, changed only if
* CODEC_ID_NONE was requested
*
* @return 0 if OK, AVERROR_xxx on error
*/
int ff_alsa_open(AVFormatContext *s, snd_pcm_stream_t mode,
unsigned int *sample_rate,
- int channels, enum CodecID *codec_id);
+ int channels, enum AVCodecID *codec_id);
/**
* Close the ALSA PCM.
@@ -67,15 +67,15 @@ typedef struct {
* out: actually selected sample rate
* @param channels number of channels
- * @param codec_id in: requested CodecID or CODEC_ID_NONE;
- * out: actually selected CodecID, changed only if
- * CODEC_ID_NONE was requested
+ * @param codec_id in: requested AVCodecID or AV_CODEC_ID_NONE;
+ * out: actually selected AVCodecID, changed only if
+ * AV_CODEC_ID_NONE was requested
*
* @return 0 if OK, AVERROR_xxx on error